
package cz.upol.pja.lecture08.beans;

import cz.upol.pja.lecture08.NewUserMessage;
import java.util.Properties;
import javax.annotation.Resource;
import javax.ejb.MessageDriven;
import javax.jms.Message;
import javax.jms.MessageListener;
import javax.mail.Authenticator;
import javax.mail.PasswordAuthentication;
import javax.mail.Session;
import javax.mail.Transport;
import javax.mail.internet.AddressException;
import javax.mail.internet.InternetAddress;
import javax.mail.internet.MimeMessage;

/**
 * MessageBean, ktera odesle email v pri obdrzeni zpravy.
 * Prebira konfiguraci z AS (mail/lecture08).
 */

@MessageDriven(mappedName = "java:app/jms/newUserTopic")
public class EmailBean implements MessageListener {
	
    @Resource(lookup = "mail/lecture08")
    private Session session;
    
    @Override
    public void onMessage(Message message) {
        try {
            NewUserMessage data = message.getBody(NewUserMessage.class);
            sendEmail(data);
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    
    private void sendEmail(NewUserMessage data) throws Exception {
	// pvoolene debugovani
	session.setDebugOut(System.out);
	session.setDebug(true);
	
	MimeMessage message = new MimeMessage(session);
        message.setRecipient(javax.mail.Message.RecipientType.TO, new InternetAddress("john-doe@example.com"));
        message.setSubject("New User");
        message.setSender(new InternetAddress("noreply@example.com"));
        message.setText("new user " + data.getFirstName() + " " + data.getSecondName());
        Transport.send(message);    
    }


//
//    alternativni zpusob, jak poslat email
//    (reseni, pokud GlassFish neumoznuje nakonfigurovat zdroj mail/lecture08)
//  
    
//    private final int port = 25;
//    private final String host = "smtp.upol.cz";
//    
//    // nepouzije se autorizace
//    private final boolean auth = false;
//    private final String username = "john-doe";
//    private final String passwd = "nbusr123";
//
//    
//    private void sendEmail(NewUserMsg data) throws Exception {
//        Properties props = new Properties();
//        props.put("mail.smtp.host", host);
//        props.put("mail.smtp.port", port);
//        
//        Authenticator authenticator = null;
//        if (auth) {
//            props.put("mail.smtp.auth", true);
//            authenticator = new Authenticator() {
//                private final PasswordAuthentication pa = new PasswordAuthentication(username, passwd);
//
//                @Override
//                protected PasswordAuthentication getPasswordAuthentication() {
//                    return pa;
//                }
//            };
//        }
//        
//        Session session = Session.getInstance(props, authenticator);
//        session.setDebug(true);
//        
//        
//        MimeMessage message = new MimeMessage(session);
//        message.setRecipient(javax.mail.Message.RecipientType.TO, new InternetAddress("john-doe@example.com"));
//        message.setSubject("New User");
//        message.setSender(new InternetAddress("noreply@example.com"));
//        message.setText("new user " + data.getFirstName() + " " + data.getSecondName());
//        Transport.send(message);
//    }
  
}
